Liealgebras Submodule
=====================

.. module:: beluga.liepack.domain.liealgebras

Introduction
------------

Base Class Reference
--------------------

.. autoclass:: LieAlgebra
    :members: get_dimension, get_shape, set_vector, random, zero

.. autoclass:: rn

.. autoclass:: so

.. autoclass:: sp
